@@ -663,7 +663,7 @@ clearlooks_draw_menu_item_separator (cairo_t                   *cr,
 {
 	cairo_save (cr);
 	cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
-	ge_cairo_set_color (cr, &colors->shade[8]);
+	ge_cairo_set_color (cr, &colors->fg[0]);
 
 	if (separator->horizontal)
 		cairo_rectangle (cr, x, y, width, 1);
@@ -895,7 +895,7 @@ clearlooks_draw_separator (cairo_t *cr,
                            const SeparatorParameters  *separator,
                            int x, int y, int width, int height)
 {
-	CairoColor color = colors->shade[2];
+	CairoColor color = colors->fg[0];
 	CairoColor hilight;
 	ge_shade_color (&colors->bg[0], 1.065, &hilight);
 
